package com.ynet.life.action;

import com.dynamicode.invoked.Standard;
import com.dynamicode.parsereturncode.ParseReturnCode;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.life.base.LifeAction;
import com.ynet.life.base.LifeConstants;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/* loaded from: com_ynet_life_action.jar:com/ynet/life/action/DynamicCodeAction.class */
public class DynamicCodeAction extends LifeAction {
    public static final String PSN_GET_VERIFYCODE = "DYN0000000";
    public static final String VERIFY = "DYN0000010";
    public static final String TOKEN_BIND = "DYN0000020";
    public static final String TOKEN_UNBIND = "DYN0000030";
    public static final String TOKEN_SYN_ONE = "DYN0000040";
    public static final String TOKEN_SYN_TWO = "DYN0000050";
    public static final String UNLOCK = "DYN0000060";
    public static final String LOST = "DYN0000070";
    public static final String UNLOST = "DYN0000080";
    public static final String SMS_BIND = "DYN0000090";
    public static final String SMS_UNBIND = "DYN0000100";
    public static final String GET_SMSCODE = "DYN0000110";
    public static final String GET_CARDCODE = "DYN0000120";
    public static final String REPLACE_CARD = "DYN0000130";
    public static final String QUERY_BINF_INF = "DYN0000140";
    private String operTyp;
    private String dynamicPass1;
    private String dynamicPass2;
    private String customerId;
    private String chTokenSn;
    private String mobileNo;
    private String passCode;
    private String cardVerifyNo;
    private String cardSeqNo;
    private String bindInfRes;
    private String security;

    public List getConfigList() {
        List<HashMap<String, String>> serverList = new ArrayList<>();
        HashMap<String, String> server1 = new HashMap<>();
        server1.put("host", LifeConstants.dynamicIp);
        server1.put("port", LifeConstants.dynamicPort);
        server1.put("key", LifeConstants.dynamicKey);
        serverList.add(server1);
        return serverList;
    }

    public String execute(Context context) throws GENEException {
        try {
            if (this.operTyp == null) {
                throw new TranFailException("EBLN0183", "操作类型为空");
            }
            if (this.customerId == null) {
                this.customerId = "session_customerId";
            }
            String customerIdValue = getContextDataByKey(context, this.customerId);
            if (this.operTyp.equals(PSN_GET_VERIFYCODE)) {
                getPsnVerifyCode(getContextDataByKey(context, this.security), context, customerIdValue, getContextDataByKey(context, this.mobileNo));
                return "0";
            }
            if (this.operTyp.equals(VERIFY)) {
                String securityValue = getContextDataByKey(context, this.security);
                if (securityValue.charAt(2) == '1' || securityValue.charAt(3) == '1' || securityValue.charAt(4) == '1') {
                    verify(customerIdValue, getContextDataByKey(context, this.dynamicPass1));
                    return "0";
                }
                return "0";
            }
            if (this.operTyp.equals(TOKEN_BIND)) {
                bindToken(customerIdValue, getContextDataByKey(context, this.chTokenSn));
                return "0";
            }
            if (this.operTyp.equals(TOKEN_UNBIND)) {
                unbindToken(customerIdValue);
                return "0";
            }
            if (this.operTyp.equals(TOKEN_SYN_ONE)) {
                synOne(customerIdValue, getContextDataByKey(context, this.dynamicPass1), getContextDataByKey(context, this.dynamicPass2));
                return "0";
            }
            if (this.operTyp.equals(TOKEN_SYN_TWO)) {
                synTwo(customerIdValue, getContextDataByKey(context, this.dynamicPass1));
                return "0";
            }
            if (this.operTyp.equals(UNLOCK)) {
                unlock(customerIdValue);
                return "0";
            }
            if (this.operTyp.equals(LOST)) {
                lost(customerIdValue);
                return "0";
            }
            if (this.operTyp.equals(UNLOST)) {
                unlost(customerIdValue);
                return "0";
            }
            if (this.operTyp.equals(SMS_BIND)) {
                bindSms(customerIdValue);
                return "0";
            }
            if (this.operTyp.equals(SMS_UNBIND)) {
                unbindSms(customerIdValue);
                return "0";
            }
            if (this.operTyp.equals(GET_SMSCODE)) {
                if (this.passCode == null || this.passCode.equals("")) {
                    throw new TranFailException("EBLN0183", "输入域不能为空");
                }
                generateSmsCode(context, customerIdValue, getContextDataByKey(context, this.mobileNo));
                return "0";
            }
            if (this.operTyp.equals(GET_CARDCODE)) {
                if (this.cardVerifyNo == null || this.cardVerifyNo.equals("") || this.cardSeqNo == null || this.cardSeqNo.equals("")) {
                    throw new TranFailException("EBLN0183", "输入域不能为空");
                }
                generateCardCode(context, customerIdValue);
                return "0";
            }
            if (this.operTyp.equals(REPLACE_CARD)) {
                replaceCard(customerIdValue, getContextDataByKey(context, this.chTokenSn));
                return "0";
            }
            if (this.operTyp.equals(QUERY_BINF_INF)) {
                if (this.bindInfRes == null || this.bindInfRes.equals("")) {
                    throw new TranFailException("EBLN0183", "输入域不能为空");
                }
                queryBindInf(context, customerIdValue);
                return "0";
            }
            return "0";
        } catch (GENEException empe) {
            Trace.logError("LifeAction", empe.getMessage(), empe);
            throw empe;
        }
    }

    public String getContextDataByKey(Context context, String key) throws GENEException {
        if (key == null || key.equals("")) {
            Trace.logWarning("LifeAction", "输入域不能为空");
            throw new TranFailException("EBLN0183", "输入域不能为空");
        }
        return (String) context.getDataValue(key);
    }

    public void log4ParseReturnCode(ParseReturnCode returnMsg) throws GENEException {
        Trace.logDebug(GENEConstance.GENE_DYN_PASSWORD, "返回码：" + returnMsg.getRetcode() + ", 返回信息：" + returnMsg.getRetdesc());
    }

    public void getPsnVerifyCode(String security, Context context, String customerIdValue, String mobileNoValue) throws GENEException {
        if (security.charAt(2) == '1') {
            if (this.passCode == null || this.passCode.equals("")) {
                Trace.logWarning("LifeAction", "输入域不能为空");
                throw new TranFailException("EBLN0183", "输入域不能为空");
            }
            generateSmsCode(context, customerIdValue, mobileNoValue);
        }
        if (security.charAt(4) == '1') {
            if (this.cardVerifyNo == null || this.cardVerifyNo.equals("") || this.cardSeqNo == null || this.cardSeqNo.equals("")) {
                Trace.logWarning("LifeAction", "输入域不能为空");
                throw new TranFailException("EBLN0183", "输入域不能为空");
            }
            generateCardCode(context, customerIdValue);
        }
    }

    public void verify(String customerIdValue, String dynamicPass1Value) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).CheckDynamicPwdByUser(customerIdValue, dynamicPass1Value);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "动态密码验证失败，失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "动态密码验证失败，失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void bindToken(String customerIdValue, String chTokenSnValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).AppBind(customerIdValue, chTokenSnValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc(), false);
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "绑定失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "绑定失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void unbindToken(String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).AppUnbind(customerIdValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "解绑失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "解绑失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void synOne(String customerIdValue, String dynamicPass1Value, String dynamicPass2Value) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).TokenSyncOne(customerIdValue, dynamicPass1Value, dynamicPass2Value);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "同步失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "同步失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void synTwo(String customerIdValue, String dynamicPass1Value) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).TokenSync(customerIdValue, dynamicPass1Value);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "同步失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "同步失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void unlock(String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).TokenUnlock(customerIdValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "解锁失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "解锁失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void lost(String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).TokenLost(customerIdValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "挂失失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "挂失失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void unlost(String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).TokenUnlost(customerIdValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "解挂失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "解挂失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void bindSms(String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).msgTokenBind(customerIdValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "绑定失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "绑定失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void unbindSms(String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).msgTokenUnBind(customerIdValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc());
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "解绑失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "解绑失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void generateSmsCode(Context context, String customerIdValue, String mobileNoValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            ParseReturnCode returnMsg2 = new Standard(getConfigList()).getMsgTokenPsw(customerIdValue, mobileNoValue);
            log4ParseReturnCode(returnMsg2);
            if (!"0".equals(returnMsg2.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg2.getRetdesc());
            }
            context.setDataValue(this.passCode, returnMsg2.getPasscode());
        } catch (Exception e) {
            Trace.logError("LifeAction", "获取短信动态密码失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "获取短信动态密码失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void generateCardCode(Context context, String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            ParseReturnCode returnMsg2 = new Standard(getConfigList()).getCardChallenge(customerIdValue);
            log4ParseReturnCode(returnMsg2);
            if (!"0".equals(returnMsg2.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg2.getRetdesc(), false);
            }
            context.setDataValue(this.cardVerifyNo, returnMsg2.getResponsecode());
            context.setDataValue(this.cardSeqNo, returnMsg2.getResponsenumber());
        } catch (Exception e) {
            Trace.logError("LifeAction", "获取刮刮卡序号和挑战码失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "获取刮刮卡序号和挑战码失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void replaceCard(String customerIdValue, String chTokenSnValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).replaceCard(customerIdValue, chTokenSnValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                throw new TranFailException("EBLN0183", returnMsg.getRetdesc(), false);
            }
        } catch (Exception e) {
            Trace.logError("LifeAction", "更换失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "更换失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public void queryBindInf(Context context, String customerIdValue) throws GENEException {
        ParseReturnCode returnMsg = null;
        try {
            returnMsg = new Standard(getConfigList()).tokenQuery(customerIdValue);
            log4ParseReturnCode(returnMsg);
            if (!"0".equals(returnMsg.getRetcode())) {
                context.setDataValue(this.bindInfRes, (Object) null);
            }
            context.setDataValue(this.bindInfRes, returnMsg.getTokenStateBean());
        } catch (Exception e) {
            Trace.logError("LifeAction", "绑定信息查询失败,失败原因：" + returnMsg.getRetdesc(), e);
            throw new TranFailException("EBLN0183", "绑定信息查询失败,失败原因：" + returnMsg.getRetdesc(), e);
        }
    }

    public String getCardSeqNo() {
        return this.cardSeqNo;
    }

    public void setCardSeqNo(String cardSeqNo) {
        this.cardSeqNo = cardSeqNo;
    }

    public String getCardVerifyNo() {
        return this.cardVerifyNo;
    }

    public void setCardVerifyNo(String cardVerifyNo) {
        this.cardVerifyNo = cardVerifyNo;
    }

    public String getChTokenSn() {
        return this.chTokenSn;
    }

    public void setChTokenSn(String chTokenSn) {
        this.chTokenSn = chTokenSn;
    }

    public String getCustomerId() {
        return this.customerId;
    }

    public void setCustomerId(String customerId) {
        this.customerId = customerId;
    }

    public String getDynamicPass1() {
        return this.dynamicPass1;
    }

    public void setDynamicPass1(String dynamicPass1) {
        this.dynamicPass1 = dynamicPass1;
    }

    public String getDynamicPass2() {
        return this.dynamicPass2;
    }

    public void setDynamicPass2(String dynamicPass2) {
        this.dynamicPass2 = dynamicPass2;
    }

    public String getMobileNo() {
        return this.mobileNo;
    }

    public void setMobileNo(String mobileNo) {
        this.mobileNo = mobileNo;
    }

    public String getOperTyp() {
        return this.operTyp;
    }

    public void setOperTyp(String operTyp) {
        this.operTyp = operTyp;
    }

    public String getPassCode() {
        return this.passCode;
    }

    public void setPassCode(String passCode) {
        this.passCode = passCode;
    }

    public String getBindInfRes() {
        return this.bindInfRes;
    }

    public void setBindInfRes(String bindInfRes) {
        this.bindInfRes = bindInfRes;
    }

    public String getSecurity() {
        return this.security;
    }

    public void setSecurity(String security) {
        this.security = security;
    }

    public static void main(String[] args) {
        DynamicCodeAction dc = new DynamicCodeAction();
        try {
            dc.bindToken("13002700000618", "1000000119");
        } catch (GENEException empe) {
            Trace.logError("LifeAction", empe.getMessage(), empe);
        }
    }
}
